<?php
/**
 * elegantPURL Lite JS handler
 *
 * PHP version 5
 * 
 * @package   elegantPURL Lite
 * @author    Chris Lema (cflema@gmail.com) and Justin Kussow (jdkussow@gmail.com)
 * @copyright Copyright (c)2011 ALL RIGHTS RESERVED
 */
class epurl_js {
    function add_scripts() {
        // needed by WP
        wp_enqueue_script( 'jquery' );
        
        // ePurl scripts
        wp_register_script( 'epurl', EPURL_URL . 'includes/epurl.js', 
				array('jquery', 'jquery-ui-core', 'jquery-ui-dialog', 
					'jquery-ui-draggable', 'jquery-ui-resizable'), 
				'1.0' );
        wp_enqueue_script( 'epurl' );
        
        $epurl_params = array(
            'ajax_url' => (is_ssl()) ? str_replace('http:', 'https:', admin_url('admin-ajax.php')) : str_replace('https:', 'http:', admin_url('admin-ajax.php')),
            'login_nonce' => wp_create_nonce("epurl-user-action")
        );
        wp_localize_script( 'epurl', 'epurl_params', $epurl_params );
    }
    
    function add_action_listeners() {
        add_action( 'wp_ajax_epurl_savemember', array( __CLASS__, 'save_member_request' ) );
        add_action( 'wp_ajax_epurl_deletemember', array( __CLASS__, 'delete_member_request' ) );
        add_action( 'wp_ajax_epurl_validatelandingpage', array( __CLASS__, 'validate_landing_page_request' ) );
    }
    
    function save_member_request() {
        check_ajax_referer( 'epurl-user-action', 'security' );

        $result = array();
        $mData = $_POST['memberData'];  
        
        $continue = true;
        
        if ( $mData['id'] < 1)
            $continue = elegantpurl::validate_landing_page( $mData['campaign_id'], $mData['landing_page'] );
        
        if ( $continue ) {
            $wp_error = false;
            $campaign = get_post($mData['campaign_id']);
            $fName = esc_attr($mData['fields']['first_name']['value']);
            $lName = esc_attr($mData['fields']['last_name']['value']);
            
            $email = '';
            if ( $mData['fields']['email'] )
                $email = esc_attr($mData['fields']['email']['value']);
            
            $member = array(            
                'ID' => ($mData['id'] > -1) ? $mData['id'] : null,
                'comment_status' => 'closed',
                'ping_status' => 'closed',
                'post_title' => $campaign->post_name . '/' . $fName . ' ' . $lName,
                'post_name' => strtolower($campaign->post_name . '_' . $fName . '_' . $lName),
                'post_parent' => $campaign->ID,
                'post_status' => 'private',
                'post_type' => 'epurl_member'
            );

            $memberId = wp_insert_post( $member, $wp_error );
            if ( $memberId > 0 && !is_wp_error($wp_error) ) {
                update_post_meta( $memberId, 'epurl_landing_page', $mData['landing_page'] );
                update_post_meta( $memberId, 'epurl_first_name', $fName );
                update_post_meta( $memberId, 'epurl_last_name', $lName );
                update_post_meta( $memberId, 'epurl_email', $email );
                update_post_meta( $memberId, 'epurl_fields', $mData['fields'] );
                
                if ( $mData['id'] > -1 ) {
                    $result['action'] = 'updated';
                } else {
                    $mData['id'] = $memberId;
                    $result['action'] = 'created';                
                }
                $mData = array_merge( $mData, $mData['fields'] );
                unset( $mData['fields'] );
                unset( $mData['campaign_id'] );
                
                $result['success'] = true;
                $result['newData'] = $mData;
            } else {
                $result['success'] = false;
                if ( is_wp_error($wp_error) )
                    $result['error'] = $wp_error->get_error_message();
                else
                    $result['error'] = "A problem occured while saving the campaign member.";
            }
        } else {
            $result['success'] = false;
            $result['duplicateLP'] = true;
            $result['error'] = "A problem occured saving the campaign member: landing page is not unique.";
        }
        
        echo json_encode( $result );
        die();
    }
    
    function delete_member_request() {
        check_ajax_referer( 'epurl-user-action', 'security' );

        $result = array();
        $wp_error = false;
        $memberId = esc_attr( $_POST['memberId'] );
                
        $wp_error = wp_delete_post( $memberId, true ); 
        if ( !is_wp_error($wp_error) ) {
            $result['success'] = true;
        } else {
            $result['success'] = false;
            if ( is_wp_error($wp_error) )
                $result['error'] = $wp_error->get_error_message();
            else
                $result['error'] = "A problem occured while deleting the campaign member.";
        }        
        
        echo json_encode( $result );
        die();
    }
    
    function validate_landing_page_request() {
        check_ajax_referer( 'epurl-user-action', 'security' );
        
        $campaignId = esc_attr( $_POST['campaignId'] );
        $landingPage = esc_attr( $_POST['landingPage'] );
        
        $result = array();
        $result['success'] = elegantpurl::validate_landing_page( $campaignId, $landingPage );
        
        echo json_encode( $result );
        die();
    }
}
epurl_js::add_action_listeners();
?>
